@@ -1,4 +1,4 @@
-# $Id: Directory.pm 47266 2018-01-05 09:02:36Z anton $
+# $Id: Directory.pm 48415 2019-10-10 16:06:09Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -74,7 +74,16 @@ sub accountTemporarilyDisabled {
 
 
 sub stuff {
+
 	my $joinArrays = shift;
+
+#	warn "stuff: " ;
+#	if ($joinArrays){
+#		warn "joinArrays!";
+#	} else {
+#		warn "no joinArays!";
+#	}
+#	
 	my $entry = $self->ldapEntry;
 
 	my %userinfo;
@@ -126,13 +135,24 @@ sub stuff {
 
     my $uid = $userinfo{uid};
     $userinfo{studentaccount} = $uid =~ /^(s\d{6}|u\d{7})$/i;
-
+	
 	while (my ($key, $value) = each (%userinfo)){
-		if (defined($joinArrays)) {
-			$value = join(', ', @{$value}) if ref($value) eq 'ARRAY';
-			$value = '' unless $value;
+
+#		warn "key: $key";
+		if (defined($value)){
+#			warn "value: $value";
+			if (defined($joinArrays)) {
+				if (ref($value) eq 'ARRAY'){
+					$value = join(', ', @{$value});
+					$value = '' unless $value;
+					warn "new value: $value";
+				}
+			}
+			if (ref($value eq 'SCALAR')){
+				utf8::decode($value) or utf8::upgrade($value);
+			}
+			
 		}
-		utf8::decode($value) or utf8::upgrade($value);
 		$userinfo{$key} = $value;
 	}
 
@@ -201,6 +221,7 @@ sub ldap_connection {
 	  # onerror is o.a. NODIG om te reageren op foutieve authenticatie         
 	  # nadeel is gvd dat je niet meer kunt zien waar je error vandaan komt :(
 
+		
 		if ($ssl eq 'on' ) {
 			warn "ssl connection to: $server" if $self->debug;
 			$ldap = Net::LDAPS->new(
