@@ -1,4 +1,4 @@
-# $Id: SQL.pm 47078 2017-10-10 11:51:05Z anton $
+# $Id: SQL.pm 48414 2019-10-10 16:01:49Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/SQL.pm $
 #
 # Er wordt door deze app geschreven naar adb123, die wordt eens in het uur ofzo gelezen
@@ -85,6 +85,13 @@ sub new {
 	$self = super;
 	my $db = DBI->connect($self->dsn, $self->user, $self->pass, $dbi_options);
 
+	if (!$db){
+		warn "DBIConnect: Could not connect with: $self->dsn, $self->pass "; 
+	} else {
+		warn "DBIConnect: Succesfully connected with: $self->dsn";
+	}
+	
+	
 	$self->{getAccount} = $db->prepare("SELECT anr, usernaam FROM pgprd.adb413usernaam WHERE anr = ? ");
 	$self->{getUsername} = $db->prepare("SELECT usernaam FROM pgprd.adb413usernaam WHERE anr = ? ");
 
